# -*- coding: utf-8 -*-
from codecs import open
import os
import re
from setuptools import setup

with open(os.path.join('jaconv', '__init__.py'), 'r', encoding='utf8') as f:
    version = re.compile(r".*__version__ = '(.*?)'",
                         re.S).match(f.read()).group(1)

setup(name='jaconv',
      packages=['jaconv'],
      package_data={
          "jaconv": ["py.typed", "*.pyi"],
      },
      version=version,
      license='MIT License',
      platforms=['POSIX', 'Windows', 'Unix', 'MacOS'],
      description='Pure-Python Japanese character interconverter for '
      'Hiragana, Katakana, Hankaku, Zenkaku and more',
      author='Yukino Ikegami',
      author_email='yknikgm@gmail.com',
      url='https://github.com/ikegami-yukino/jaconv',
      keywords=[
          'Japanese converter', 'Japanese', 'text preprocessing',
          'half-width kana', 'Hiragana', 'Katakana', 'Hankaku', 'Zenkaku',
          'transliteration', 'Julius'
      ],
      classifiers=[
          'Development Status :: 4 - Beta', 'Intended Audience :: Developers',
          'Intended Audience :: Information Technology',
          'License :: OSI Approved :: MIT License',
          'Natural Language :: Japanese', 'Operating System :: MacOS',
          'Operating System :: Microsoft', 'Operating System :: POSIX',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12', 'Topic :: Text Processing'
      ],
      data_files=[('', ['README.rst', 'CHANGES.rst'])],
      long_description='%s\n\n%s' %
      (open('README.rst', encoding='utf8').read(),
       open('CHANGES.rst', encoding='utf8').read()),
      test_suite='nose.collector')



import typing
from .compat import map as map
from .conv_table import H2HK_TABLE as H2HK_TABLE, H2K_TABLE as H2K_TABLE, H2Z_A as H2Z_A, H2Z_AD as H2Z_AD, H2Z_AK as H2Z_AK, H2Z_ALL as H2Z_ALL, H2Z_D as H2Z_D, H2Z_DK as H2Z_DK, H2Z_K as H2Z_K, HEP2KANA as HEP2KANA, JULIUS_LONG_VOWEL as JULIUS_LONG_VOWEL, K2H_TABLE as K2H_TABLE, KANA2HEP as KANA2HEP, SMALL_KANA2BIG_KANA as SMALL_KANA2BIG_KANA, Z2H_A as Z2H_A, Z2H_AD as Z2H_AD, Z2H_AK as Z2H_AK, Z2H_ALL as Z2H_ALL, Z2H_D as Z2H_D, Z2H_DK as Z2H_DK, Z2H_K as Z2H_K
from _typeshed import Incomplete

consonants: Incomplete
ending_h_pattern: Incomplete

def _exclude_ignorechar(ignore: str, conv_map: typing.Dict[int, str]) -> typing.Dict[int, str]: ...
def _convert(text: str, conv_map: typing.Dict[int, str]) -> str: ...
def _translate(text: str, ignore: str, conv_map: typing.Dict[int, str]) -> str: ...
def hira2kata(text: str, ignore: str = '') -> str: ...
def hira2hkata(text: str, ignore: str = '') -> str: ...
def kata2hira(text: str, ignore: str = '') -> str: ...
def enlargesmallkana(text: str, ignore: str = '') -> str: ...
def h2z(text: str, ignore: str = '', kana: bool = True, ascii: bool = False, digit: bool = False) -> str: ...
def z2h(text: str, ignore: str = '', kana: bool = True, ascii: bool = False, digit: bool = False) -> str: ...
def normalize(text: str, mode: str = 'NFKC') -> str: ...
def kana2alphabet(text: str) -> str: ...
def alphabet2kana(text: str) -> str: ...
def hiragana2julius(text: str) -> str: ...



from . import jaconv
from _typeshed import Incomplete

__all__ = ['hira2kata', 'hira2hkata', 'kata2hira', 'h2z', 'z2h', 'hankaku2zenkaku', 'zenkaku2hankaku', 'normalize', 'kana2alphabet', 'alphabet2kana', 'kata2alphabet', 'alphabet2kata', 'hiragana2julius', 'enlargesmallkana']

hira2kata = jaconv.hira2kata
hira2hkata = jaconv.hira2hkata
kata2hira = jaconv.kata2hira
h2z = jaconv.h2z
z2h = jaconv.z2h
han2zen = jaconv.h2z
zen2han = jaconv.z2h
hankaku2zenkaku = jaconv.h2z
zenkaku2hankaku = jaconv.z2h
normalize = jaconv.normalize
kana2alphabet = jaconv.kana2alphabet
alphabet2kana = jaconv.alphabet2kana
kata2alphabet: Incomplete
alphabet2kata: Incomplete
hiragana2julius = jaconv.hiragana2julius
enlargesmallkana = jaconv.enlargesmallkana
